@@ -105,7 +105,7 @@ START_TEST(event_conversion_device_notify)
 					   EV_KEY, BTN_MIDDLE,
 					   EV_KEY, BTN_LEFT,
 					   -1, -1);
-	li = libinput_path_create_context(&simple_interface, NULL);
+	li = litest_create_context();
 	litest_restore_log_handler(li); /* use the default litest handler */
 	libinput_path_add_device(li, libevdev_uinput_get_devnode(uinput));
 
@@ -144,7 +144,7 @@ START_TEST(event_conversion_device_notify)
 		libinput_event_destroy(event);
 	}
 
-	libinput_unref(li);
+	litest_destroy_context(li);
 	libevdev_uinput_destroy(uinput);
 
 	ck_assert_int_gt(device_added, 0);
@@ -669,6 +669,7 @@ START_TEST(timer_offset_bug_warning)
 	struct litest_device *dev = litest_current_device();
 	struct libinput *li = dev->libinput;
 	int warning_triggered = 0;
+	void *old_user_data;
 
 	litest_enable_tap(dev->libinput_device);
 	litest_drain_events(li);
@@ -678,6 +679,7 @@ START_TEST(timer_offset_bug_warning)
 
 	litest_timeout_tap();
 
+	old_user_data = libinput_get_user_data(li);
 	libinput_set_user_data(li, &warning_triggered);
 	libinput_log_set_handler(li, timer_offset_warning);
 	libinput_dispatch(li);
@@ -685,6 +687,49 @@ START_TEST(timer_offset_bug_warning)
 	/* triggered for touch down and touch up */
 	ck_assert_int_eq(warning_triggered, 2);
 	litest_restore_log_handler(li);
+
+	libinput_set_user_data(li, old_user_data);
+}
+END_TEST
+
+static void timer_delay_warning(struct libinput *libinput,
+				enum libinput_log_priority priority,
+				const char *format,
+				va_list args)
+{
+	int *warning_triggered = (int*)libinput_get_user_data(libinput);
+
+	if (priority == LIBINPUT_LOG_PRIORITY_ERROR &&
+	    strstr(format, "event processing lagging behind by"))
+		(*warning_triggered)++;
+}
+
+
+START_TEST(timer_delay_bug_warning)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libinput *li = dev->libinput;
+	int warning_triggered = 0;
+	void *old_user_data;
+
+	old_user_data = libinput_get_user_data(li);
+	litest_drain_events(li);
+
+	for (int i = 0; i < 10; i++) {
+		litest_button_click(dev, BTN_LEFT, true);
+		libinput_dispatch(li);
+		litest_button_click(dev, BTN_LEFT, false);
+		msleep(11);
+
+		libinput_set_user_data(li, &warning_triggered);
+		libinput_log_set_handler(li, timer_delay_warning);
+		libinput_dispatch(li);
+	}
+
+
+	ck_assert_int_ge(warning_triggered, 1);
+	litest_restore_log_handler(li);
+	libinput_set_user_data(li, old_user_data);
 }
 END_TEST
 
@@ -756,7 +801,8 @@ START_TEST(timer_flush)
 
 	litest_delete_device(keyboard);
 	litest_delete_device(touchpad);
-	libinput_unref(li);
+
+	litest_destroy_context(li);
 }
 END_TEST
 
@@ -855,6 +901,7 @@ TEST_COLLECTION(misc)
 	litest_add_deviceless("config:status string", config_status_string);
 
 	litest_add_for_device("timer:offset-warning", timer_offset_bug_warning, LITEST_SYNAPTICS_TOUCHPAD);
+	litest_add_for_device("timer:delay-warning", timer_delay_bug_warning, LITEST_MOUSE);
 	litest_add_no_device("timer:flush", timer_flush);
 
 	litest_add_no_device("misc:fd", fd_no_event_leak);
